@@ -1,3 +1,4 @@
+import dotenv
 import importlib
 import importlib.util
 import logging
@@ -9,7 +10,7 @@ from enum import Enum
 from textwrap import dedent
 from threading import Event
 from types import ModuleType
-from typing import Any, Callable, NewType, Type, TypeVar, cast
+from typing import Any, Callable, NewType, Type, TypeVar, cast, Optional
 
 import lastmile_utils.lib.core.api as core_utils
 import result
@@ -29,6 +30,7 @@ logging.getLogger("werkzeug").disabled = True
 logging.basicConfig(format=core_utils.LOGGER_FMT)
 LOGGER = logging.getLogger(__name__)
 
+# TODO: saqadri - use logs directory to save logs
 log_handler = logging.FileHandler("editor_flask_server.log", mode="a")
 formatter = logging.Formatter(core_utils.LOGGER_FMT)
 log_handler.setFormatter(formatter)
@@ -64,6 +66,26 @@ class EditServerConfig(core_utils.Record):
     log_level: str | int = "INFO"
     server_mode: ServerMode = ServerMode.PROD
     parsers_module_path: str = "aiconfig_model_registry.py"
+    env_file_path: Optional[str] = None
+
+    @field_validator("server_mode", mode="before")
+    def convert_to_mode(
+        cls, value: Any
+    ) -> ServerMode:  # pylint: disable=no-self-argument
+        if isinstance(value, str):
+            try:
+                return ServerMode[value.upper()]
+            except KeyError as e:
+                raise ValueError(f"Unexpected value for mode: {value}") from e
+        return value
+
+
+class StartServerConfig(core_utils.Record):
+    server_port: int = 8080
+    log_level: str | int = "INFO"
+    server_mode: ServerMode = ServerMode.PROD
+    parsers_module_path: str = "aiconfig_model_registry.py"
+    env_file_path: Optional[str] = None
 
     @field_validator("server_mode", mode="before")
     def convert_to_mode(
@@ -82,6 +104,7 @@ class ServerState:
     aiconfigrc_path: str = os.path.join(os.path.expanduser("~"), ".aiconfigrc")
     aiconfig: AIConfigRuntime | None = None
     events: dict[str, Event] = field(default_factory=dict)
+    env_file_path: str | None = None
 
 
 class AIConfigRC(core_utils.Record):
@@ -268,12 +291,23 @@ def safe_load_from_disk(
 
 
 def init_server_state(
-    app: Flask, edit_config: EditServerConfig, aiconfigrc_path: str
+    app: Flask,
+    initialization_settings: StartServerConfig | EditServerConfig,
+    aiconfigrc_path: str,
 ) -> Result[None, str]:
-    LOGGER.info("Initializing server state")
-    _load_user_parser_module_if_exists(edit_config.parsers_module_path)
+    LOGGER.info("Initializing server state for 'edit' command")
+    _load_user_parser_module_if_exists(
+        initialization_settings.parsers_module_path
+    )
     state = get_server_state(app)
     state.aiconfigrc_path = aiconfigrc_path
+    state.env_file_path = initialization_settings.env_file_path
+
+    if isinstance(initialization_settings, StartServerConfig):
+        # The aiconfig will be loaded later, when the editor sends the payload.
+        return Ok(None)
+    # else:
+    edit_config = initialization_settings
 
     assert state.aiconfig is None
     if os.path.exists(edit_config.aiconfig_path):
